"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appSync = void 0;
const Errors_1 = require("./Errors");
const buildResponse = (response) => {
    if (response instanceof Errors_1.AppSyncError) {
        return {
            data: response.data,
            errorInfo: response.info,
            errorType: response.type,
            errorMessage: response.message,
        };
    }
    else if (response instanceof Error) {
        // re-throw returned errors
        throw response;
    }
    else {
        return { data: response };
    }
};
const appSync = () => {
    return {
        onError: async (handler) => {
            const response = buildResponse(handler.error);
            if (Array.isArray(handler.event)) {
                const resp = new Array(handler.event.length);
                handler.response = resp.fill(response);
            }
            else {
                handler.response = response;
            }
            return false;
        },
        after: async (handler) => {
            const { response } = handler;
            if (Array.isArray(handler.event)) {
                if (!Array.isArray(response) ||
                    handler.event.length !== response.length) {
                    throw new Error('BatchInvoke: The response does not match the request payload');
                }
                handler.response = response.map(buildResponse);
            }
            else {
                handler.response = buildResponse(response);
            }
        },
    };
};
exports.appSync = appSync;
